@@ -65,17 +65,6 @@ class TimePoint(InstanceRegistry, DumpableState):
         """uuid for the time point"""
         return self.UUID_PREFIX + self._uuid
 
-    @property
-    def _timepoint_basic_dict(self) -> dict:
-        """basic dictionary for any TimePoint class or subclass"""
-        # todo update this when the dependency diamond is resolved
-        return {
-            'time_delta': self.time_delta,
-            'uuid': self.uuid,
-            'name': self.name,
-            'class': self.__class__.__name__,
-        }
-
     @classmethod
     def get_instance(cls, key: str) -> "TimePoint":
         """
@@ -93,7 +82,14 @@ class TimePoint(InstanceRegistry, DumpableState):
 
     def as_dict(self) -> dict:
         """Returns a key: value representation of the instance"""
-        return self._timepoint_basic_dict
+        dct = super(TimePoint, self).as_dict()
+        dct.update({
+            'time_delta': self.time_delta,
+            'uuid': self.uuid,
+            'name': self.name,
+            'class': self.__class__.__name__,
+        })
+        return dct
 
     def sample_time_from_reference(self, reference_time: float):
         """
@@ -126,7 +122,7 @@ class TimePoint(InstanceRegistry, DumpableState):
         return self.__gt__(other) or self.__eq__(other)
 
 
-class ActionTimePoint(ExecutionSequence, TimePoint):
+class ActionTimePoint(TimePoint, ExecutionSequence):
     UUID_PREFIX = 'atp-'
 
     def __init__(self,
@@ -289,7 +285,7 @@ class ActionTimePoint(ExecutionSequence, TimePoint):
     def as_dict(self) -> dict:
         """Returns a key: value representation of the instance"""
         dct = super(ActionTimePoint, self).as_dict()
-        dct.update(self._timepoint_basic_dict)
         # todo decide how to include relative start times
+        dct['configuration'] = dct['configuration']['name']  # todo remove when legacy requirements are updated
         return dct
 
